// FILENAME:	CTF_Energy_Barrier.cs
//
// AUTHOR:		Gen. Raven [M.I.B.]
//------------------------------------------------------------------------------
// Stealth Detection - Set to true & players with a "/" in front of their
// will be detected when they join or leave the server.

// Defaulted off since im *hoping* ancients will run this and they already 
// have stealth detect onAdd.
$stealthDetectOnAdd = false;
$stealthDetectOnRemove = true;  //Ancients has none when a player leaves

//------------------------------------------------------------------------------
$missionName = "CTF_Energy_Barrier";

$ancientsCTFRules = true;     //AutoHeal after kill or cap, fast/no shutdown pads

$maxFlagCount  = 8;           // no of flags required by a team to end the game
$flagValue     = 5;          // points your team gets for capturing
$carrierValue  = 2;          //  "      "    "    "    " killing carrier
$killPoints    = 1;
$deathPoints   = 1;
$flagTime = 300;

exec("multiplayerStdLib.cs");
exec("CTFstdLib.cs");

function setDefaultMissionOptions()
{
	$server::TeamPlay = true;
	$server::AllowDeathmatch = false;
	$server::AllowTeamPlay = true;	

	$server::AllowTeamRed = false;
	$server::AllowTeamBlue = true;
	$server::AllowTeamYellow = false;
	$server::AllowTeamPurple = true;

   // what can the server admin choose for available teams
   $server::disableTeamRed = true;
   $server::disableTeamBlue = false;
   $server::disableTeamYellow = true;
   $server::disableTeamPurple = false;
}

$bluePower1 = true;
$bluePower2 = true;
$purplePower1 = true;
$purplePower2 = true;
$blueDown = false;
$purpleDown = false;

function onMissionLoad()
{
   cdAudioCycle("Terror", "Mechsoul", "NewTech");
   setGameInfo("<f2>GAME TYPE:<f0>  Capture the Flag\n\n<f2>MISSION<f0>   CTF_Energy_Barrier\n\n<f2>CREATOR:<f0>  Gen. Raven [M.I.B.]\n\n<f0>Each team has two generators that power an energy barrier around their flag. Enemy vehicles cannot pass through the barrier until both generators are destroyed. Once a team's flag has been captured, that team's energy barrier will come back online. You can download CTF_Energy_Barrier & other missions made by Gen. Raven [M.I.B.] in the \"MIB Map Packs\" on the MIB Website at www.starsiegemeninblack.cjb.net.");
}

function onMissionStart()
{
   initGlobalVars();
   marsSounds();

   $blueField1 = getObjectId("Missiongroup\\BlueFields\\blueField1");
   $blueField2 = getObjectId("Missiongroup\\BlueFields\\blueField2");
   $blueField3 = getObjectId("Missiongroup\\BlueFields\\blueField3");
   $blueField4 = getObjectId("Missiongroup\\BlueFields\\blueField4");
   $blueField5 = getObjectId("Missiongroup\\BlueFields\\blueField5");
   $blueField6 = getObjectId("Missiongroup\\BlueFields\\blueField6");
   $blueField7 = getObjectId("Missiongroup\\BlueFields\\blueField7");
   $blueField8 = getObjectId("Missiongroup\\BlueFields\\blueField8");
   $purpleField1 = getObjectId("Missiongroup\\PurpleFields\\purpleField1");
   $purpleField2 = getObjectId("Missiongroup\\PurpleFields\\purpleField2");
   $purpleField3 = getObjectId("Missiongroup\\PurpleFields\\purpleField3");
   $purpleField4 = getObjectId("Missiongroup\\PurpleFields\\purpleField4");
   $purpleField5 = getObjectId("Missiongroup\\PurpleFields\\purpleField5");
   $purpleField6 = getObjectId("Missiongroup\\PurpleFields\\purpleField6");
   $purpleField7 = getObjectId("Missiongroup\\PurpleFields\\purpleField7");
   $purpleField8 = getObjectId("Missiongroup\\PurpleFields\\purpleField8");
   $bluegen1 = getObjectId("Missiongroup\\bluegen1");
   $bluegen2 = getObjectId("Missiongroup\\bluegen2");
   $purplegen1 = getObjectId("Missiongroup\\purplegen1");
   $purplegen2 = getObjectId("Missiongroup\\purplegen2");
   $generator = getObjectId("Missiongroup\\Generator");
}

function player::onAdd(%player)
{
   if(($stealthDetectOnAdd == true)&&(strAlign(1, left, getname(%player))=="/"))
   {
        say(0,0,"<f4>"@getname(%player)@" joined the game","alarm2.wav");
        messagebox(%player,"This server is equipped with an anti-stealth detection system. The slash on your name has been detected. All players have been alerted to your presence.");
   }
   say(%player, 0, "Welcome to CTF Energy Barrier! Each team has two generators that power an energy barrier around their flag. Enemy vehicles cannot pass through the barrier until both generators are destroyed. Once a team's flag has been captured, that team's energy barrier will come back online. You can download CTF_Energy_Barrier & other missions made by Gen. Raven [M.I.B.] on the MIB Website at www.starsiegemeninblack.cjb.net.");
  
   //Activate Rock's Admin Pack if its being used
   RocksPlayerOnAdd(%player);
}

function player::onRemove(%player)
{
   if(($stealthDetectOnRemove == true)&&(strAlign(1, left, getname(%player))=="/"))
   {
      say(0,0,"<f4>"@getname(%player)@" left the game","alarm2.wav");
   }
}

function copyObject(%object,%name)
{
   storeObject(%object, "copyObject.tmp");
   if(%name=="")
   {
      %copy = loadObject(getObjectName(%object), "copyObject.tmp");
   }
   else
   {
      %copy = loadObject(%name, "copyObject.tmp");
   }
   return %copy;
}

function sayTeam(%team, %text, %wav)
{
   %count = playerManager::getPlayerCount();
   for(%i = 0; %i < %count; %i++)
   {
      %player = playerManager::getPlayerNum(%i);
      if(getTeam(%player)==%team)
      {
         say(%player, %player, %text, %wav);
      }
   }
}

function newGenerators(%team)
{
   if(%team=="Blue Team")
   {
      $bluePower1 = true;
      $bluePower2 = true;
      $blueDown = false;
      deleteObject($bluegen1);
      deleteObject($bluegen2);
      $bluegen1 = copyObject($generator);
      $bluegen2 = copyObject($generator);
      addToSet("Missiongroup\\Gens",$bluegen1);
      addToSet("Missiongroup\\Gens",$bluegen2);
      setTeam($bluegen1,"Blue Team");
      setTeam($bluegen2,"Blue Team");
      setStaticShapeShortName($bluegen1,"Blue Generator #1");
      setStaticShapeShortName($bluegen2,"Blue Generator #2");
      setPosition($bluegen1, -344,-264,96);
      setPosition($bluegen2, 342,-264,96);
      schedule("say(0,20,\"<f5>Blue Team's Energy Barrier is back online.\",\"sfx_flyer_on.wav\");",3);
      for(%i=1;%i<=8;%i++)
      {
         setShapeVisibility($blueField[%i],true);
      }
   }
   else if(%team=="Purple Team")
   {
      $purplePower1 = true;
      $purplePower2 = true;
      $purpleDown = false;
      deleteObject($purplegen1);
      deleteObject($purplegen2);
      $purplegen1 = copyObject($generator);
      $purplegen2 = copyObject($generator);
      addToSet("Missiongroup\\Gens",$purplegen1);
      addToSet("Missiongroup\\Gens",$purplegen2);
      setTeam($purplegen1,"Purple Team");
      setTeam($purplegen2,"Purple Team");
      setStaticShapeShortName($purplegen1,"Purple Generator #1");
      setStaticShapeShortName($purplegen2,"Purple Generator #2");
      setPosition($purplegen1, 347,744,96);
      setPosition($purplegen2, -340,744,96);
      schedule("say(0,20,\"<f5>Purple Team's Energy Barrier is back online.\",\"sfx_flyer_on.wav\");",3);
      for(%i=1;%i<=8;%i++)
      {
         setShapeVisibility($purpleField[%i],true);
      }
   }
}

function structure::ondestroyed(%destroyed,%destroyer)
{
   if(%destroyed==$bluegen1)
   {
      $bluepower1 = false;
      sayTeam("Blue Team", "<f5>"@getname(%destroyer)@" destroyed Blue Generator #1!", "friend_struct_des.wav");
      sayTeam("Purple Team", "<f5>"@getname(%destroyer)@" destroyed Blue Generator #1!", "ene_struct_dest.wav");
   }
   else if(%destroyed==$bluegen2)
   {
      $bluepower2 = false;
      sayTeam("Blue Team", "<f5>"@getname(%destroyer)@" destroyed Blue Generator #2!", "friend_struct_des.wav");
      sayTeam("Purple Team", "<f5>"@getname(%destroyer)@" destroyed Blue Generator #2!", "ene_struct_dest.wav");
   }
   else if(%destroyed==$purplegen1)
   {
      $purplepower1 = false;
      sayTeam("Purple Team", "<f5>"@getname(%destroyer)@" destroyed Purple Generator #1!", "friend_struct_des.wav");
      sayTeam("Blue Team", "<f5>"@getname(%destroyer)@" destroyed Purple Generator #1!", "ene_struct_dest.wav");
   }
   else if(%destroyed==$purplegen2)
   {
      $purplepower2 = false;
      sayTeam("Purple Team", "<f5>"@getname(%destroyer)@" destroyed Purple Generator #2!", "friend_struct_des.wav");
      sayTeam("Blue Team", "<f5>"@getname(%destroyer)@" destroyed Purple Generator #2!", "ene_struct_dest.wav");
   }
   if(($blueDown==false)&&($bluepower1==false)&&($bluepower2==false))
   {
      $blueDown = true;
      for(%i=1;%i<=8;%i++)
      {
         setShapeVisibility($blueField[%i],false);
      }
      schedule("say(0,20,\"<f5>Blue Team's Energy Barrier is down!\",\"sfx_flyer_off.wav\");",3);
   }
   if(($purpleDown==false)&&($purplepower1==false)&&($purplepower2==false))
   {
      $purpleDown = true;
      for(%i=1;%i<=8;%i++)
      {
         setShapeVisibility($purpleField[%i],false);
      }
      schedule("say(0,21,\"<f5>Purple Team's Energy Barrier is down!\",\"sfx_flyer_off.wav\");",3);
   }
}

function blueKillTrig::trigger::onenter(%trigger,%vehicleId)
{
   if($blueDown==false)
   {
      if(getTeam(%vehicleId)!="Blue Team")
      {
         %player = playermanager::vehicleIdtoPlayerNum(%vehicleId);
         %player.fielddeath = true;
         healObject(%vehicleId,-50000);
         playSound(%player, "sfx_electrical_bzzt.wav", IDPRF_2D);
         messagebox(%player,"You must first destroy the enemy generators to disable the energy barrier around the flag!");
      }
   }
}

function purpleKillTrig::trigger::onenter(%trigger,%vehicleId)
{
   if($purpleDown==false)
   {
      if(getTeam(%vehicleId)!="Purple Team")
      {
         %player = playermanager::vehicleIdtoPlayerNum(%vehicleId);
         %player.fielddeath = true;
         healObject(%vehicleId,-50000);
         playSound(%player, "sfx_electrical_bzzt.wav", IDPRF_2D);
         messagebox(%player,"You must first destroy the enemy generators to disable the energy barrier around the flag!");
      }
   }
}

function getGenStatus(%a)
{
   %team = getTeamNameFromTeamId(%a);
   %gensLeft = 0;
   if(%team=="Blue Team")
   {
      if($bluePower1==true)
      {
         %gensLeft++;
      }
      if($bluePower2==true)
      {
         %gensLeft++;
      }
   }
   if(%team=="Purple Team")
   {
      if($purplePower1==true)
      {
         %gensLeft++;
      }
      if($purplePower2==true)
      {
         %gensLeft++;
      }
   }
   return %gensLeft;  
}

function onMissionEnd()
{
   flushConsoleScheduler();
   deleteObject("Missiongroup\\Gens");
}

//Pad stuff
function ZenHeal::trigger::onEnter(%this, %object)
{
   // tell user pad has been entered
   Zen::onEnter(%this, %object, *IDMULT_CHAT_HEALPAD, true, true);  
}

function ZenHeal::trigger::onContact(%this, %object)
{
   if($ancientsCTFRules==true)
   {
      Zen::work(%this, %object, 1000, 0, 0, false);
   }
   else
   {
      Zen::work(%this, %object, 1000, 0, 0, true);
   }
}

function ZenHeal::trigger::onLeave(%this, %object)
{
   Zen::onLeave(%this, %object); 
}

function ZenAmmo::trigger::onEnter(%this, %object)
{
   // tell user pad has been entered
   Zen::onEnter(%this, %object, *IDMULT_CHAT_AMMOPAD, true, true);  
}

function ZenAmmo::trigger::onContact(%this, %object)
{
   if($ancientsCTFRules==true)
   {
      Zen::work(%this, %object, 0, 25, 0, false);
   }
   else
   {
      Zen::work(%this, %object, 0, 25, 0, true);
   }
}

function ZenAmmo::trigger::onLeave(%this, %object)
{
   Zen::onLeave(%this, %object); 
}

//From CTFStdLib.cs - Modified functions
//----------------------------------------------------------
// vehicle::onadd()
// vehicle::onDestroyed()
// checkFlagRetrieved()
// initScoreBoard()
//----------------------------------------------------------
function vehicle::onAdd(%vehicleId)
{
   %player = playermanager::vehicleIdtoPlayerNum(%vehicleId);
   %player.fieldDeath = false;
   if($ancientsCTFRules==true)
   {
      $limit = 2;
      %c = getWeaponCount(%vehicleId);
      %i = 0;
      %missles = 0;
      while(%i<%c)
      {
         %id = getWeaponId(%vehicleId,%i);
         if(((%id>=124)&&(%id<=136))||(%id==147)||(%id==142)||(%id==150))
         {
            %missles++;
         }
         %i++;
      }
      if(%missles>$limit)
      {
         healObject(%vehicleId,-50000);
         say(%player,%player,"<f5>THIS SERVER DOES NOT ALLOW MORE THAN <f0>"@$limit@"<f5> MISSLES/MINES/SGUNS/RAD GUNS PER VEHICLE!","rules_violated.wav");
      }
   }

   %team = getTeam(playerManager::vehicleIdToPlayerNum(%vehicleId));
   %color = teamToColor(%team);
   %flagKey = strcat(%color, "FlagCount");

   adjTeamCount(%team, 1);

   //if the flag isn't at the base, but no one has it, correct situation
   if(dataRetrieve(0, %flagKey) && !dataRetrieve(0, strcat(%color, "FlagCarried")))
   {
   	setFlag(%team, true);
   }   
}

function vehicle::onDestroyed(%destroyed,%destroyer)
{
   if($ancientsCTFRules==true)
   {
      if(playermanager::vehicleIdToPlayerNum(%destroyer)!=0)
      {
         schedule("healobject("@%destroyer@",99999);",8);
         schedule("healobject("@%destroyer@",99999);",8);
         schedule("healobject("@%destroyer@",99999);",8);
         schedule("healobject("@%destroyer@",99999);",8);
         schedule("healobject("@%destroyer@",99999);",8);
      }
   }
   %team = getTeam(%destroyed);
   adjTeamCount(%team, -1);
   %teamCount = getTeamPlayerCount(%team);      

   if(%teamCount < 1)
   {
	   setFlag(%team, false);					
   }

   %color = dataRetrieve(%destroyed, "hasFlag");
   %flagTeam = colorToTeam(%color);
   
   // if the destroyed vehicle has a flag, it goes back to it's base
   if (%color != "")
   {
      playerDropsFlag(%destroyed);
      
      // let everyone know this guy drops the flag
      %str =
         *IDMULT_CHAT_SURRENDER_FLAG_1 @
         getName( %destroyed )         @
         *IDMULT_CHAT_SURRENDER_FLAG_2 @ 
         %flagTeam                     @
         *IDMULT_CHAT_SURRENDER_FLAG_3;
      
      %soundFile = "";   
      if(%flagTeam == *IDSTR_TEAM_RED)
      {
         %soundFile = "red_flag_sur.wav";
      }
      else if(%flagTeam == *IDSTR_TEAM_BLUE)
      {
         %soundFile = "blue_flag_sur.wav";
      }
      else if(%flagTeam == *IDSTR_TEAM_YELLOW)
      {
         %soundFile = "yel_flag_sur.wav";
      }
      else
      {
         %soundFile = "purp_flag_sur.wav";
      }   
      
      say( 0, 0, %str, %soundFile );

            
      if($scoringFreeze == false)
      {     
         // destroyer's team gets credit for killing the carrier
         %destroyerTeam = getTeam(%destroyer);  
      
         // only give points if destroyed recovered his/her own flag
         if(%destroyerTeam == colorToTeam(%color))
         {
            %key = strcat(teamToColor(getTeam(%destroyer)), "CarriersKilled");
            dataStore(0, %key, 1 + dataRetrieve(0, %key));
            
            // player gets credit, too
            %player = playerManager::vehicleIdToPlayerNum(%destroyer);
            if(%player != 0)
            {
               %player.carriersKilled = %player.carriersKilled + 1;
            }
         }

         // echo the surrender to the console for logging
         echo(*IDSTR_CONSOLE_CTF_SURRENDER @ " " @ playerManager::vehicleIdToPlayerNum(%destroyed));                        
      }	  
   }
   else
   {
      // not a flag carrier ... is it an enemy?
      if($scoringFreeze == false)
      {
         if(getTeam(%destroyed) != getTeam(%destroyer))
         {
            %player = playerManager::vehicleIdToPlayerNum(%destroyer);
            if(%player != 0)
            {
               %player.genericKills = %player.genericKills + 1;
            }
         }
      }
   }
   
   // enforce the rules
   if(
      (getTeam(%destroyed) == getTeam(%destroyer)) &&
      (%destroyed != %destroyer)
   )
   {
      antiTeamKill(%destroyer);
   }

   vehicle::onDestroyedLog(%destroyed, %destroyer);
   
   // give the death messages...
   %player = playermanager::vehicleIdtoPlayerNum(%destroyed);
   if(%player.fieldDeath==true)
   {
      say(0,0,getName(%player)@" was vaporized by the energy barrier.");
   }
   else
   {
      %message = getFancyDeathMessage(getHUDName(%destroyed), getHUDName(%destroyer));
      if(%message != "")
      {
         say( 0, 0, %message);
      }
   }
}

function checkFlagRetrieved(%team, %vehicle)
{
   %color = teamToColor(%team);

   // you made it back to your own base, do you have any other teams' flags?
   if (dataRetrieve(%vehicle, "hasFlag") == "") 
      { return; }

   // is the player's team flag at his base when he brings back the enemy's flag?
   if (dataRetrieve(0, strcat(%color, "FlagCount")) != 0) 
      { return; }

   // player is no longer carrying the flag
   %hasColor = dataRetrieve(%vehicle, "hasFlag");
   %flagTeam = colorToTeam(%hasColor);
   playerDropsFlag(%vehicle);

   if($scoringFreeze == false)
   {
      // player's team gets credit for stealing the flag
      %collectedKey = strcat(teamToColor(getTeam(%vehicle)), "FlagsCollected");
      %collectedCount = dataRetrieve(0, %collectedKey);
      %collectedCount = %collectedCount + 1;
      dataStore(0, %collectedKey, %collectedCount);
      
      // player gets credit also
      %player = playerManager::vehicleIdToPlayerNum(%vehicle);
      %player.flagsCollected = %player.flagsCollected + 1;

      // echo the capture to the console for logging
      echo(*IDSTR_CONSOLE_CTF_CAPTURE @ " " @ playerManager::vehicleIdToPlayerNum(%vehicle));      	               

      if(getTeam(%vehicle)=="Blue Team")
      {
         newGenerators("Purple Team");
      }
      if(getTeam(%vehicle)=="Purple Team")
      {
         newGenerators("Blue Team");
      }
      if($ancientsCTFRules==true)
      {
         healObject(%vehicle, 99999);
         healObject(%vehicle, 99999);
         healObject(%vehicle, 99999);
         healObject(%vehicle, 99999);
         healObject(%vehicle, 99999);
      }
      %needMore = $maxFlagCount - %collectedCount;
      if (%needMore <= 0)
      {
         winEvent(getTeam(%vehicle));
      }
   }
  
   // let everyone know what happened
   %str =
      *IDMULT_CHAT_CAPTURE_FLAG_1 @
      getName( %vehicle ) @
      *IDMULT_CHAT_CAPTURE_FLAG_2 @ 
      colorToTeam(%hasColor) @
      *IDMULT_CHAT_CAPTURE_FLAG_3;
   
   %soundFile = "";
   if(%flagTeam == *IDSTR_TEAM_RED)
   {
      %soundFile = "red_flag_cap.wav";
   }
   else if(%flagTeam == *IDSTR_TEAM_BLUE)
   {
      %soundFile = "blue_flag_cap.wav";
   }
   else if(%flagTeam == *IDSTR_TEAM_YELLOW)
   {
      %soundFile = "yel_flag_cap.wav";
   }
   else
   {
      %soundFile = "purp_flag_cap.wav";
   }
   
   say( 0, 0, %str, %soundFile );      
}

function initScoreBoard()
{
   deleteVariables("$ScoreBoard::PlayerColumn*");
   deleteVariables("$ScoreBoard::TeamColumn*");

   // Player ScoreBoard column headings
   $ScoreBoard::PlayerColumnHeader1 = *IDMULT_SCORE_TEAM;
   $ScoreBoard::PlayerColumnHeader2 = *IDMULT_SCORE_SCORE;
   $ScoreBoard::PlayerColumnHeader3 = *IDMULT_SCORE_FLAGS;
   $ScoreBoard::PlayerColumnHeader4 = *IDMULT_SCORE_CARRIER_KILLS;
   $ScoreBoard::PlayerColumnHeader5 = *IDMULT_SCORE_KILLS;
   $ScoreBoard::PlayerColumnHeader6 = *IDMULT_SCORE_DEATHS;   

   // Player ScoreBoard column functions
   $ScoreBoard::PlayerColumnFunction1 = "getTeam";
   $ScoreBoard::PlayerColumnFunction2 = "getPlayerScore";
   $ScoreBoard::PlayerColumnFunction3 = "getPlayerFlags";
   $ScoreBoard::PlayerColumnFunction4 = "getPlayerCarriersKilled";
   $ScoreBoard::PlayerColumnFunction5 = "getPlayerGenericKills";
   $ScoreBoard::PlayerColumnFunction6 = "getDeaths";


   //Team ScoreBoard column headings
   $ScoreBoard::TeamColumnHeader1 = *IDMULT_SCORE_SCORE;
   $ScoreBoard::TeamColumnHeader2 = *IDMULT_SCORE_PLAYERS;
   $ScoreBoard::TeamColumnHeader3 = "Generators Remaining";
   $ScoreBoard::TeamColumnHeader4 = *IDMULT_SCORE_FLAGS;
    
   // Team ScoreBoard column functions
   $ScoreBoard::TeamColumnFunction1 = "getTeamScore";
   $ScoreBoard::TeamColumnFunction2 = "getNumberOfPlayersOnTeam";
   $ScoreBoard::TeamColumnFunction3 = "getGenStatus";
   $ScoreBoard::TeamColumnFunction4 = "getTeamFlags";

   
   // tell server to process all the scoreboard definitions defined above
   serverInitScoreBoard();   
}